Class: Rotulus::DB::PostgreSQL
- Defined in:
- lib/rotulus/db/postgresql.rb
Instance Method Summary collapse
-
#default_nulls_order(sort_direction) ⇒ Object
PG considers NULL values to be larger than any other values.
Methods inherited from Database
#name, #nullable_order_sql, #nulls_in_default_order?, #nulls_order_sql, #order_sql, #reversed_nullable_order_sql, #reversed_order_sql, #select_all_sql
Instance Method Details
#default_nulls_order(sort_direction) ⇒ Object
PG considers NULL values to be larger than any other values. www.postgresql.org/docs/current/queries-order.html
6 7 8 9 10 |
# File 'lib/rotulus/db/postgresql.rb', line 6 def default_nulls_order(sort_direction) return :last if sort_direction == :asc :first end |